# requests-gracedb

requests-gracedb provides a generic REST API client for [GraceDB] and similar
LIGO/Virgo API services. It uses the powerful [Requests] package for reliable
and high-throughput HTTP connection pooling.

[GraceDB]: https://gracedb.ligo.org/
[Requests]: http://requests.readthedocs.io/
